%global momorel 4

# momonga 7 has capabilities of EL5
%global el5 1

Summary: A GNU source-level debugger for C, C++, Java and other languages
Name: gdb

# Set version to contents of gdb/version.in.
# NOTE: the FSF gdb versions are numbered N.M for official releases, like 6.3
# and, since January 2005, X.Y.Z.date for daily snapshots, like 6.3.50.20050112 # (daily snapshot from mailine), or 6.3.0.20040112 (head of the release branch).
Version: 7.1

Release: %{momorel}m%{?dist}
License: GPLv3+
Group: Development/Debuggers

# Do not provide URL for snapshots as the file lasts there only for 2 days.
# ftp://sourceware.org/pub/gdb/snapshots/branch/gdb-%{version}.tar.bz2
# ftp://sourceware.org/pub/gdb/releases/gdb-%{version}.tar.bz2
Source0: ftp://sourceware.org/pub/gdb/releases/gdb-%{version}.tar.bz2
NoSource: 0
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
URL: http://gnu.org/software/gdb/

### include local configuration
%{?include_specopt}
### default configurations
#  If you'd like to change these configurations, please copy them to
# ~/rpmbuild/specopt/gdb.specopt and edit it.
%{?!do_test: %global do_test 0}

# For our convenience
%define gdb_src gdb-%{version}
%define gdb_build build-%{_target_platform}

%if 0%{?_with_debug:1}
# Define this if you want to skip the strip step and preserve debug info.
# Useful for testing.
%define __debug_install_post : > %{_builddir}/%{?buildsubdir}/debugfiles.list
%define debug_package %{nil}
%endif

# Make sure we get rid of the old package gdb64, now that we have unified
# support for 32-64 bits in one single 64-bit gdb.
%ifarch ppc64
Obsoletes: gdb64 < 5.3.91
%endif

%if 0%{?el5:1}
Obsoletes: gdb-gdbserver
%endif

%if 0%{!?el5:1}
%if 0%{!?_with_upstream:1}
# The last Rawhide release was (no dist tag) pstack-1.2-7.2.2
Obsoletes: pstack < 1.2-7.2.2.1
Provides: pstack = 1.2-7.2.2.1
%endif # 0%{!?_with_upstream:1}
%endif # 0%{!?el5:1}

# GDB patches have the format `gdb-<version>-bz<red-hat-bz-#>-<desc>.patch'.
# They should be created using patch level 1: diff -up ./gdb (or gdb-6.3/gdb).

# Cleanup any leftover testsuite processes as it may stuck mock(1) builds.
Source2: gdb-orphanripper.c

# Man page for gstack(1).
Source3: gdb-gstack.man

# libstdc++ pretty printers from GCC SVN HEAD (4.5 experimental).
%define libstdcxxpython libstdc++-v3-python-r155978
Source4: %{libstdcxxpython}.tar.bz2

# Work around out-of-date dejagnu that does not have KFAIL
Patch1: gdb-6.3-rh-dummykfail-20041202.patch

# Match the Fedora's version info.
Patch2: gdb-6.3-rh-testversion-20041202.patch

# Check that libunwind works - new test then fix
Patch3: gdb-6.3-rh-testlibunwind-20041202.patch

# Use convert_from_func_ptr_addr on the solib breakpoint address;
# simplifies and makes more consistent the logic.
Patch104: gdb-6.3-ppcdotsolib-20041022.patch

# Better parse 64-bit PPC system call prologues.
Patch105: gdb-6.3-ppc64syscall-20040622.patch

# Stop a backtrace when a zero PC is encountered.
Patch106: gdb-6.3-framepczero-20040927.patch

# Include the pc's section when doing a symbol lookup so that the
# correct symbol is found.
Patch111: gdb-6.3-ppc64displaysymbol-20041124.patch

# Fix upstream `set scheduler-locking step' vs. upstream PPC atomic seqs.
Patch112: gdb-6.6-scheduler_locking-step-sw-watchpoints2.patch
# Make upstream `set scheduler-locking step' as default.
Patch260: gdb-6.6-scheduler_locking-step-is-default.patch

# Add a wrapper script to GDB that implements pstack using the
# --readnever option.
Patch118: gdb-6.3-gstack-20050411.patch

# VSYSCALL and PIE
Patch122: gdb-6.3-test-pie-20050107.patch
Patch389: gdb-archer-pie-addons.patch
Patch394: gdb-archer-pie-addons-keep-disabled.patch

# Get selftest working with sep-debug-info
Patch125: gdb-6.3-test-self-20050110.patch

# Test support of multiple destructors just like multiple constructors
Patch133: gdb-6.3-test-dtorfix-20050121.patch

# Fix to support executable moving
Patch136: gdb-6.3-test-movedir-20050125.patch

# Fix to support unwinding syscalls in ia64 corefiles
# Patch138: gdb-6.3-ia64-corefile-fix-20050127.patch

# Fix gcore for threads
Patch140: gdb-6.3-gcore-thread-20050204.patch

# Stop while intentionally stepping and the thread exit is met.
Patch141: gdb-6.6-step-thread-exit.patch
Patch259: gdb-6.3-step-thread-exit-20050211-test.patch

# Prevent gdb from being pushed into background
Patch142: gdb-6.3-terminal-fix-20050214.patch

# Test sibling threads to set threaded watchpoints for x86 and x86-64
Patch145: gdb-6.3-threaded-watchpoints2-20050225.patch

# Fix printing of inherited members
Patch148: gdb-6.3-inheritance-20050324.patch

# Do not issue warning message about first page of storage for ia64 gcore
Patch153: gdb-6.3-ia64-gcore-page0-20050421.patch

# Security errata for untrusted .gdbinit
Patch157: gdb-6.3-security-errata-20050610.patch

# IA64 sigtramp prev register patch
Patch158: gdb-6.3-ia64-sigtramp-frame-20050708.patch

# IA64 gcore speed-up patch
Patch160: gdb-6.3-ia64-gcore-speedup-20050714.patch

# Notify observers that the inferior has been created
Patch161: gdb-6.3-inferior-notification-20050721.patch

# Fix ia64 info frame bug
Patch162: gdb-6.3-ia64-info-frame-fix-20050725.patch

# Verify printing of inherited members test
Patch163: gdb-6.3-inheritancetest-20050726.patch

# Add readnever option
Patch164: gdb-6.3-readnever-20050907.patch

# Fix ia64 gdb problem with user-specified SIGILL handling
Patch169: gdb-6.3-ia64-sigill-20051115.patch

# Allow option to continue backtracing past a zero pc value
Patch170: gdb-6.3-bt-past-zero-20051201.patch

# Use bigger numbers than int.
Patch176: gdb-6.3-large-core-20051206.patch

# Fix debuginfo addresses resolving for --emit-relocs Linux kernels (BZ 203661).
Patch188: gdb-6.5-bz203661-emit-relocs.patch

# Security patch: avoid stack overflows in dwarf expression computation.
# CVE-2006-4146
Patch190: gdb-6.5-dwarf-stack-overflow.patch

# Support TLS symbols (+`errno' suggestion if no pthread is found) (BZ 185337).
Patch194: gdb-6.5-bz185337-resolve-tls-without-debuginfo-v2.patch

# Fix TLS symbols resolving for objects with separate .debug file (-debuginfo).
Patch195: gdb-6.5-tls-of-separate-debuginfo.patch

# Fix TLS symbols resolving for shared libraries with a relative pathname.
# The testsuite needs `gdb-6.5-tls-of-separate-debuginfo.patch'.
Patch196: gdb-6.5-sharedlibrary-path.patch

# Suggest fixing your target architecture for gdbserver(1) (BZ 190810).
# FIXME: It could be autodetected.
Patch199: gdb-6.5-bz190810-gdbserver-arch-advice.patch

# Fix `gcore' command for 32bit inferiors on 64bit hosts.
Patch201: gdb-6.5-gcore-i386-on-amd64.patch

# Testcase for deadlocking on last address space byte; for corrupted backtraces.
Patch211: gdb-6.5-last-address-space-byte-test.patch

# Improved testsuite results by the testsuite provided by the courtesy of BEA.
Patch208: gdb-6.5-BEA-testsuite.patch

# Fix readline segfault on excessively long hand-typed lines.
Patch209: gdb-6.5-readline-long-line-crash.patch
Patch213: gdb-6.5-readline-long-line-crash-test.patch

# Fix bogus 0x0 unwind of the thread's topmost function clone(3) (BZ 216711).
Patch214: gdb-6.5-bz216711-clone-is-outermost.patch

# Test sideeffects of skipping ppc .so libs trampolines (BZ 218379).
Patch216: gdb-6.5-bz218379-ppc-solib-trampoline-test.patch

# Fix lockup on trampoline vs. its function lookup; unreproducible (BZ 218379).
Patch217: gdb-6.5-bz218379-solib-trampoline-lookup-lock-fix.patch

# Find symbols properly at their original (included) file (BZ 109921).
Patch225: gdb-6.5-bz109921-DW_AT_decl_file-test.patch

# Update PPC unwinding patches to their upstream variants (BZ 140532).
Patch229: gdb-6.3-bz140532-ppc-unwinding-test.patch

# Testcase for exec() from threaded program (BZ 202689).
Patch231: gdb-6.3-bz202689-exec-from-pthread-test.patch

# Backported fixups post the source tarball.
Patch232: gdb-upstream.patch

# Testcase for PPC Power6/DFP instructions disassembly (BZ 230000).
Patch234: gdb-6.6-bz230000-power6-disassembly-test.patch

# Temporary support for shared libraries >2GB on 64bit hosts. (BZ 231832)
Patch235: gdb-6.3-bz231832-obstack-2gb.patch

# Fix prelink(8) testcase for non-root $PATH missing `/usr/sbin' (BZ 225783).
Patch240: gdb-6.6-bz225783-prelink-path.patch

# Fix debugging GDB itself - the compiled in source files paths (BZ 225783).
Patch241: gdb-6.6-bz225783-gdb-debuginfo-paths.patch

# Allow running `/usr/bin/gcore' with provided but inaccessible tty (BZ 229517).
Patch245: gdb-6.6-bz229517-gcore-without-terminal.patch

# Notify user of a child forked process being detached (BZ 235197).
Patch247: gdb-6.6-bz235197-fork-detach-info.patch

# New testcase for gcore of 32bit inferiors on 64bit hosts.
Patch249: gdb-6.6-gcore32-test.patch

# Avoid too long timeouts on failing cases of "annota1.exp annota3.exp".
Patch254: gdb-6.6-testsuite-timeouts.patch

# Support for stepping over PPC atomic instruction sequences (BZ 237572).
Patch258: gdb-6.6-bz237572-ppc-atomic-sequence-test.patch

# Link with libreadline provided by the operating system.
Patch261: gdb-6.6-readline-system.patch

# Test kernel VDSO decoding while attaching to an i386 process.
Patch263: gdb-6.3-attach-see-vdso-test.patch

# Do not hang on exit of a thread group leader (BZ 247354).
Patch265: gdb-6.6-bz247354-leader-exit-fix.patch
Patch266: gdb-6.6-bz247354-leader-exit-test.patch

# Test leftover zombie process (BZ 243845).
Patch271: gdb-6.5-bz243845-stale-testing-zombie-test.patch

# New locating of the matching binaries from the pure core file (build-id).
Patch274: gdb-6.6-buildid-locate.patch
Patch353: gdb-6.6-buildid-locate-rpm.patch
Patch415: gdb-6.6-buildid-locate-core-as-arg.patch

# Fix displaying of numeric char arrays as strings (BZ 224128).
Patch282: gdb-6.7-charsign-test.patch

# Test PPC hiding of call-volatile parameter register.
Patch284: gdb-6.7-ppc-clobbered-registers-O2-test.patch

# Testsuite fixes for more stable/comparable results.
Patch287: gdb-6.7-testsuite-stable-results.patch

# Test ia64 memory leaks of the code using libunwind.
Patch289: gdb-6.5-ia64-libunwind-leak-test.patch

# Test hiding unexpected breakpoints on intentional step commands.
Patch290: gdb-6.5-missed-trap-on-step-test.patch

# Support DW_TAG_interface_type the same way as DW_TAG_class_type (BZ 426600).
Patch293: gdb-6.7-bz426600-DW_TAG_interface_type-fix.patch
Patch294: gdb-6.7-bz426600-DW_TAG_interface_type-test.patch

# Test gcore memory and time requirements for large inferiors.
Patch296: gdb-6.5-gcore-buffer-limit-test.patch

# Test debugging statically linked threaded inferiors (BZ 239652).
#  - It requires recent glibc to work in this case properly.
Patch298: gdb-6.6-threads-static-test.patch

# Fix #include <asm/ptrace.h> on kernel-headers-2.6.25-0.40.rc1.git2.fc9.x86_64.
Patch304: gdb-6.7-kernel-headers-compat.patch

# Test GCORE for shmid 0 shared memory mappings.
Patch309: gdb-6.3-mapping-zero-inode-test.patch

# Test a crash on `focus cmd', `focus prev' commands.
Patch311: gdb-6.3-focus-cmd-prev-test.patch

# Test various forms of threads tracking across exec() (BZ 442765).
Patch315: gdb-6.8-bz442765-threaded-exec-test.patch

# Silence memcpy check which returns false positive (sparc64)
Patch317: gdb-6.8-sparc64-silence-memcpy-check.patch

# Fix memory trashing on binaries from GCC Ada (workaround GCC PR 35998).
Patch318: gdb-6.8-gcc35998-ada-memory-trash.patch

# Test a crash on libraries missing the .text section.
Patch320: gdb-6.5-section-num-fixup-test.patch

# Refuse creating watchpoints of an address value, suggested by Martin Stransky.
Patch322: gdb-6.8-constant-watchpoints.patch

# Fix compatibility with recent glibc headers.
Patch324: gdb-6.8-glibc-headers-compat.patch

# Create a single binary `gdb' autodetecting --tui by its argv[0].
Patch326: gdb-6.8-tui-singlebinary.patch

# Fix PRPSINFO in the core files dumped by gcore (BZ 254229).
Patch329: gdb-6.8-bz254229-gcore-prpsinfo.patch

# Fix register assignments with no GDB stack frames (BZ 436037).
Patch330: gdb-6.8-bz436037-reg-no-longer-active.patch

# Make the GDB quit processing non-abortable to cleanup everything properly.
Patch331: gdb-6.8-quit-never-aborts.patch

# Support DW_TAG_constant for Fortran in recent Fedora/RH GCCs.
Patch332: gdb-6.8-fortran-tag-constant.patch

# Fix attaching to stopped processes and/or pending signals.
Patch337: gdb-6.8-attach-signalled-detach-stopped.patch

# Test the watchpoints conditionals works.
Patch343: gdb-6.8-watchpoint-conditionals-test.patch

# Fix resolving of variables at locations lists in prelinked libs (BZ 466901).
Patch348: gdb-6.8-bz466901-backtrace-full-prelinked.patch

# The merged branch `archer' of: http://sourceware.org/gdb/wiki/ProjectArcher
Patch349: gdb-archer.patch
Patch420: gdb-archer-ada.patch

# Fix parsing elf64-i386 files for kdump PAE vmcore dumps (BZ 457187).
# - Turn on 64-bit BFD support, globally enable AC_SYS_LARGEFILE.
Patch360: gdb-6.8-bz457187-largefile-test.patch

# New test for step-resume breakpoint placed in multiple threads at once.
Patch381: gdb-simultaneous-step-resume-breakpoint-test.patch

# Fix GNU/Linux core open: Can't read pathname for load map: Input/output error.
Patch382: gdb-core-open-vdso-warning.patch

# Fix syscall restarts for amd64->i386 biarch.
Patch391: gdb-x86_64-i386-syscall-restart.patch

# Fix stepping with OMP parallel Fortran sections (BZ 533176).
Patch392: gdb-bz533176-fortran-omp-step.patch

# Use gfortran44 when running the testsuite on RHEL-5.
#Patch393: gdb-rhel5-gcc44.patch

# Disable warning messages new for gdb-6.8+ for RHEL-5 backward compatibility.
# Workaround RHEL-5 kernels for detaching SIGSTOPped processes (BZ 498595).
Patch335: gdb-rhel5-compat.patch

# Fix regression by python on ia64 due to stale current frame.
Patch397: gdb-follow-child-stale-parent.patch

# Workaround ccache making lineno non-zero for command-line definitions.
Patch403: gdb-ccache-workaround.patch

# Implement `info common' for Fortran.
Patch404: gdb-fortran-common-reduce.patch
Patch405: gdb-fortran-common.patch

# Fix Fortran logical-kind=8 (BZ 465310).
Patch406: gdb-fortran-logical8.patch

# Testcase for "Do not make up line information" fix by Daniel Jacobowitz.
Patch407: gdb-lineno-makeup-test.patch

# Test power7 ppc disassembly.
Patch408: gdb-ppc-power7-test.patch

# Revert: Add -Wunused-function to compile flags.
Patch412: gdb-unused-revert.patch

# Fix i386+x86_64 rwatch+awatch before run, regression against 6.8 (BZ 541866).
Patch417: gdb-bz541866-rwatch-before-run.patch

# Remove false gdb_assert on $sp underflow.
Patch422: gdb-infcall-sp-underflow.patch

# Fix double-free on std::terminate handler (Tom Tromey, BZ 562975).
Patch429: gdb-bz562975-std-terminate-double-free.patch

# PIE: Fix back re-reun.
Patch430: gdb-pie-rerun.patch

# Do not consider memory error on reading _r_debug->r_map as fatal (BZ 576742).
Patch432: gdb-solib-memory-error-nonfatal.patch

# testsuite: Fix unstable results of gdb.base/prelink.exp.
Patch433: gdb-6.7-testsuite-stable-results-prelink.patch 

# [patch 1/6] PIE: Attach binary even after re-prelinked underneath
# [patch 2/6] PIE: Attach binary even after ld.so re-prelinked underneath
# [patch 3/6] PIE: Fix occasional error attaching i686 binary
Patch434: gdb-pie-1of6-reprelinked-bin.patch
Patch435: gdb-pie-2of6-reprelinked-ld.patch
Patch436: gdb-pie-3of6-relocate-once.patch

# [expr-cumulative] using-directive: Fix memory leak (Sami Wagiaalla).
Patch437: gdb-using-directive-leak.patch

# Fix dangling displays in separate debuginfo (BZ 574483).
Patch438: gdb-bz574483-display-sepdebug.patch

# Support AVX registers (BZ 578250).
Patch439: gdb-bz578250-avx-01of10.patch
Patch440: gdb-bz578250-avx-02of10.patch
Patch441: gdb-bz578250-avx-03of10.patch
Patch442: gdb-bz578250-avx-04of10.patch
Patch443: gdb-bz578250-avx-05of10.patch
Patch444: gdb-bz578250-avx-06of10.patch
Patch445: gdb-bz578250-avx-07of10.patch
Patch446: gdb-bz578250-avx-08of10.patch
Patch447: gdb-bz578250-avx-09of10.patch
Patch448: gdb-bz578250-avx-10of10.patch
Patch449: gdb-bz578250-avx-10of10-ppc.patch

# Fix crash on C++ types in some debug info files (BZ 575292, Keith Seitz).
# Temporarily workaround the crash of BZ 575292 as there was now BZ 585445.
Patch451: gdb-bz575292-delayed-physname.patch
Patch455: gdb-bz575292-void-workaround.patch

# Pretty printers not well documented (BZ 570635, Tom Tromey, Jan Kratochvil).
Patch452: gdb-bz570635-prettyprint-doc1.patch
Patch453: gdb-bz570635-prettyprint-doc2.patch

# Fix crash when using GNU IFUNC call from breakpoint condition.
Patch454: gdb-bz539590-gnu-ifunc-fix-cond.patch

# Fail gracefully if the _Unwind_DebugHook arg. is optimized out (Tom Tromey).
# Make _Unwind_DebugHook independent from step-resume breakpoint (Tom Tromey).
Patch456: gdb-unwind-debughook-safe-fail.patch
Patch457: gdb-unwind-debughook-step-independent.patch

BuildRequires: ncurses-devel%{?_isa} texinfo gettext flex bison expat-devel%{?_isa}
Requires: readline%{?_isa}
BuildRequires: readline-devel%{?_isa}
%if 0%{!?el5:1}
# dlopen() no longer makes rpm-libs a mandatory dependency.
#Requires: rpm-libs%{?_isa}
BuildRequires: rpm-devel%{?_isa}
%endif # 0%{!?el5:1}
Requires: zlib%{?_isa}
BuildRequires: zlib-devel%{?_isa}
%if 0%{!?_without_python:1}
%if 0%{!?el5:1}
Requires: python-libs%{?_isa}
%else
Requires: python%{?_isa}
%endif
BuildRequires: python-devel%{?_isa}
# Temporarily before python files get moved to libstdc++.rpm
# libstdc++%{bits_other} is not present in Koji, the .spec script generating
# gdb/python/libstdcxx/ also does not depend on the %{bits_other} files.
BuildRequires: libstdc++%{?_isa}
%endif	# 0%{!?_without_python:1}

%if %{do_test}

# Ensure the devel libraries are installed for both multilib arches.
%define bits_local %{?_isa}
%define bits_other %{?_isa}
%if 0%{!?el5:1}
%ifarch s390x
%define bits_other (%{__isa_name}-32)
%else #!s390x
%ifarch ppc
%define bits_other (%{__isa_name}-64)
%else #!ppc
%ifarch sparc64 ppc64 s390x x86_64
%define bits_other (%{__isa_name}-32)
%endif #sparc64 ppc64 s390x x86_64
%endif #!ppc
%endif #!s390x
%endif #!el5

BuildRequires: sharutils dejagnu
# gcc-objc++ is not covered by the GDB testsuite.
BuildRequires: gcc gcc-c++ gcc-gfortran gcc-java gcc-objc
# Copied from prelink-0.4.2-3.fc13.
%ifarch %{ix86} alpha sparc sparcv9 sparc64 s390 s390x x86_64 ppc ppc64
# Prelink is broken on sparcv9/sparc64.
%ifnarch sparcv9 sparc64
BuildRequires: prelink
%endif
%endif

BuildRequires: gcc gcc-gfortran

# Copied from gcc-4.1.2-32.
%ifarch %{ix86} x86_64 ia64 ppc alpha
#BuildRequires: gcc-gnat
#BuildRequires: libgnat%{bits_local} libgnat%{bits_other}
%endif
BuildRequires: glibc-devel%{bits_local} glibc-devel%{bits_other}
BuildRequires: libgcc%{bits_local} libgcc%{bits_other}
# libstdc++-devel of matching bits is required only for g++ -static.
BuildRequires: libstdc++%{bits_local} libstdc++%{bits_other}
BuildRequires: libgcj%{bits_local} libgcj%{bits_other}
%if 0%{!?el5:1}
BuildRequires: glibc-static%{bits_local}
%endif
# multilib glibc-static is open Bug 488472:
#BuildRequires: glibc-static%{bits_other}
# for gcc-java linkage:
BuildRequires: zlib-devel%{bits_local} zlib-devel%{bits_other}
# Copied from valgrind-3.5.0-1.
%ifarch %{ix86} x86_64 ppc ppc64
BuildRequires: valgrind%{bits_local} valgrind%{bits_other}
%endif

%endif # %{do_test}

%ifarch ia64
%if 0%{!?el5:1}
BuildRequires: libunwind-devel >= 0.99
Requires: libunwind-devel >= 0.99
%else
BuildRequires: libunwind-devel >= 0.96-3
Requires: libunwind >= 0.96-3
%endif
%endif
 
Requires(post): info
Requires(preun): info

%description
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

%ifnarch sparcv9
%if 0%{!?el5:1}
%package gdbserver
Summary: A standalone server for GDB (the GNU source-level debugger)
Group: Development/Debuggers

%description gdbserver
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion
and printing their data.

This package provides a program that allows you to run GDB on a different machine than the one which is running the program being debugged.
%endif # !el5
%endif # sparcv9
%prep

# This allows the tarball name to be different from our
# version-release name.

%setup -q -n %{gdb_src}

# libstdc++ pretty printers.
tar xvfz %{SOURCE4}

# Files have `# <number> <file>' statements breaking VPATH / find-debuginfo.sh .
rm -f gdb/ada-exp.c gdb/ada-lex.c gdb/c-exp.c gdb/cp-name-parser.c gdb/f-exp.c
rm -f gdb/jv-exp.c gdb/m2-exp.c gdb/objc-exp.c gdb/p-exp.c

# Apply patches defined above.

# Match the Fedora's version info.
%patch2 -p1

%if 0%{!?_with_upstream:1}

%patch232 -p1
%patch349 -p1
%patch420 -p1
%patch1 -p1
%patch3 -p1

%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch111 -p1
%patch112 -p1
%patch118 -p1
%patch122 -p1
%patch125 -p1
%patch133 -p1
%patch136 -p1
%patch140 -p1
%patch141 -p1
%patch259 -p1
%patch142 -p1
%patch145 -p1
%patch148 -p1
%patch153 -p1
%patch157 -p1
%patch158 -p1
%patch160 -p1
%patch161 -p1
%patch162 -p1
%patch163 -p1
%patch164 -p1
%patch169 -p1
%patch170 -p1
%patch176 -p1
%patch188 -p1
%patch190 -p1
%patch194 -p1
%patch195 -p1
%patch196 -p1
%patch199 -p1
%patch201 -p1
%patch208 -p1
%patch209 -p1
%patch211 -p1
%patch213 -p1
%patch214 -p1
%patch216 -p1
%patch217 -p1
%patch225 -p1
%patch229 -p1
%patch231 -p1
%patch234 -p1
%patch235 -p1
%patch240 -p1
%patch241 -p1
%patch245 -p1
%patch247 -p1
%patch249 -p1
%patch254 -p1
%patch258 -p1
%patch260 -p1
%patch261 -p1
%patch263 -p1
%patch265 -p1
%patch266 -p1
%patch271 -p1
%patch274 -p1
%patch353 -p1
%patch282 -p1
%patch284 -p1
%patch287 -p1
%patch289 -p1
%patch290 -p1
%patch293 -p1
%patch294 -p1
%patch296 -p1
%patch298 -p1
%patch304 -p1
%patch309 -p1
%patch311 -p1
%patch315 -p1
%patch317 -p1
%patch318 -p1
%patch320 -p1
%patch322 -p1
%patch324 -p1
%patch326 -p1
%patch329 -p1
%patch330 -p1
%patch331 -p1
%patch332 -p1
%patch337 -p1
%patch343 -p1
%patch348 -p1
%patch360 -p1
%patch381 -p1
%patch382 -p1
%patch391 -p1
%patch392 -p1
%patch397 -p1
%patch403 -p1
%patch404 -p1
%patch405 -p1
%patch389 -p1
%patch394 -p1
%patch406 -p1
%patch407 -p1
%patch408 -p1
%patch412 -p1
%patch417 -p1
%patch422 -p1
%patch429 -p1
%patch430 -p1
%patch432 -p1
%patch433 -p1
%patch434 -p1
%patch435 -p1
%patch436 -p1
%patch437 -p1
%patch438 -p1
%patch439 -p1
%patch440 -p1
%patch441 -p1
%patch442 -p1
%patch443 -p1
%patch444 -p1
%patch445 -p1
%patch446 -p1
%patch447 -p1
%patch448 -p1
%patch449 -p1
# Avoid internal error by disabling the previous BZ 575292 fix (BZ 585445).
#patch451 -p1
%patch452 -p1
%patch453 -p1
%patch454 -p1
%patch455 -p1
%patch456 -p1
%patch457 -p1

%patch415 -p1
#%patch393 -p1
%patch335 -p1
# Patch415: gdb-6.6-buildid-locate-core-as-arg.patch
# Currently disabled for RHEL as it is a new experimental feature not present
# in FSF GDB and possibly affecting new user scripts.
%if 0%{?rhel:1}
%patch415 -p1 -R
%endif
%if 0%{!?el5:1}
#%patch393 -p1 -R
%patch335 -p1 -R
%endif

find -name "*.orig" | xargs rm -f
! find -name "*.rej" # Should not happen.

%endif # 0%{!?_with_upstream:1}

# Change the version that gets printed at GDB startup
cat > gdb/version.in << _FOO
Momonga Linux %{momonga} (%{version}-%{release})
_FOO

# Remove the info and other generated files added by the FSF release
# process.
rm -f libdecnumber/gstdint.h
rm -f bfd/doc/*.info
rm -f bfd/doc/*.info-*
rm -f gdb/doc/*.info
rm -f gdb/doc/*.info-*

%build

# Identify the build directory with the version of gdb as well as the
# architecture, to allow for mutliple versions to be installed and
# built.
# Initially we're in the %{gdb_src} directory.

rm -fr %{gdb_build}
mkdir %{gdb_build}
cd %{gdb_build}

%if %{do_test}
# g77 executable is no longer present in momonga gcc-4.x+.
g77="`which gfortran 2>/dev/null || true`"
test -z "$g77" || ln -s "$g77" ./g77
%endif

export CFLAGS="`echo $RPM_OPT_FLAGS | sed -e 's,-O3,-O2,g'`"

%if 0%{?_with_debug:1}
# --enable-werror could conflict with `-Wall -O0' but this is no longer true
# for recent GCCs.
CFLAGS="$CFLAGS -O0 -ggdb2"
%endif

../configure							\
	--prefix=%{_prefix}					\
	--libdir=%{_libdir}					\
	--sysconfdir=%{_sysconfdir}				\
	--mandir=%{_mandir}					\
	--infodir=%{_infodir}					\
	--with-gdb-datadir=%{_datadir}/gdb			\
	--with-pythondir=%{_datadir}/gdb/python			\
	--enable-gdb-build-warnings=,-Wno-unused		\
%ifnarch %{ix86} alpha ia64 ppc s390 s390x x86_64 ppc64 sparcv9 sparc64
	--disable-werror					\
%else
%if 0%{?_with_upstream:1}
	--disable-werror					\
%else
	--enable-werror						\
%endif
%endif
	--with-separate-debug-dir=/usr/lib/debug		\
	--disable-sim						\
	--disable-rpath						\
	--with-system-readline					\
	--with-expat						\
$(: ppc64 host build crashes on ppc variant of libexpat.so )	\
	--without-libexpat-prefix				\
	--enable-tui						\
%if 0%{!?_without_python:1}
	--with-python						\
%else
	--without-python					\
%endif
$(: Workaround rpm.org#76, BZ 508193 on recent OSes. )		\
$(: RHEL-5 librpm has incompatible API. )			\
%if 0%{?el5:1}
	--without-rpm						\
%else
	--with-rpm=librpm.so.1					\
%endif
%ifarch ia64
	--with-libunwind					\
%else
	--without-libunwind					\
%endif
	--enable-64-bit-bfd					\
%if 0%{?_with_debug:1}
	--enable-static --disable-shared --enable-debug		\
%endif
%ifarch sparcv9
	sparc-%{_vendor}-%{_target_os}%{?_gnu}
%else
	%{_target_platform}
%endif

%make
make info

grep '#define HAVE_ZLIB_H 1' gdb/config.h

# Copy the <sourcetree>/gdb/NEWS file to the directory above it.
cp $RPM_BUILD_DIR/%{gdb_src}/gdb/NEWS $RPM_BUILD_DIR/%{gdb_src}

%check
# Initially we're in the %{gdb_src} directory.
cd %{gdb_build}

# For now do testing only on these platforms. 
%if !%{do_test}
echo ====================TESTSUITE DISABLED=========================
%else
echo ====================TESTING=========================
cd gdb
gcc -o ./orphanripper %{SOURCE2} -Wall -lutil -ggdb2
# Need to use a single --ignore option, second use overrides first.
# No `%{?_smp_mflags}' here as it may race.
# WARNING: can't generate a core file - core tests suppressed - check ulimit
# "readline-overflow.exp" - Testcase is broken, functionality is OK.
(
  # ULIMIT required for `gdb.base/auxv.exp'.
  ulimit -H -c
  ulimit -c unlimited || :

  # Setup $CHECK as `check//unix/' or `check//unix/-m64' for explicit bitsize.
  # Never use two different bitsizes as it fails on ppc64.
  echo 'int main (void) { return 0; }' >biarch.c
  CHECK=""
  for BI in -m64 -m32 -m31 ""
  do
    # Do not use size-less options if any of the sizes works.
    # On ia64 there is no -m64 flag while we must not leave a bare `check' here
    # as it would switch over some testing scripts to the backward compatibility
    # mode: when `make check' was executed from inside the testsuite/ directory.
    if [ -z "$BI" -a -n "$CHECK" ];then
      continue
    fi
    # Do not use $RPM_OPT_FLAGS as the other non-size options will not be used
    # in the real run of the testsuite.
    if ! gcc $BI -o biarch biarch.c
    then
      continue
    fi
    CHECK="$CHECK check//unix/$BI"
  done
  # Do not try -m64 inferiors for -m32 GDB as it cannot handle inferiors larger
  # than itself.
  # s390 -m31 still uses the standard ELF32 binary format.
  gcc $RPM_OPT_FLAGS -o biarch biarch.c
  RPM_SIZE="$(file ./biarch|sed -n 's/^.*: ELF \(32\|64\)-bit .*$/\1/p')"
  if [ "$RPM_SIZE" != "64" ]
  then
    CHECK="$(echo " $CHECK "|sed 's# check//unix/-m64 # #')"
  fi

  # Disable some problematic testcases.
  # RUNTESTFLAGS='--ignore ...' is not used below as it gets separated by the
  # `check//...' target spawn and too much escaping there would be dense.
  for test in				\
    gdb.base/readline-overflow.exp	\
    gdb.base/bigcore.exp		\
  ; do
    mv -f ../../gdb/testsuite/$test ../gdb/testsuite/$test-DISABLED || :
  done

%if 0%{!?_with_upstream:1}
  # Run all the scheduled testsuite runs also in the PIE mode.
  # Upstream GDB would lock up the testsuite run for too long on its failures.
  CHECK="$(echo $CHECK|sed 's#check//unix/[^ ]*#& &/-fPIE/-pie#g')"
%endif # 0%{!?_with_upstream:1}

  ./orphanripper make %{?_smp_mflags} -k $CHECK \
$(: Serialize the output to keep the order for regression checks. ) \
%if 0%{?el5:1}
    RUNTESTFLAGS="--tool gdb" \
%endif
    || :
)
for t in sum log
do
  for file in testsuite*/gdb.$t
  do
    suffix="${file#testsuite.unix.}"
    suffix="${suffix%/gdb.$t}"
    ln $file gdb-%{_target_platform}$suffix.$t || :
  done
done
# `tar | bzip2 | uuencode' may have some piping problems in Brew.
tar cjf gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}*.{sum,log}
uuencode gdb-%{_target_platform}.tar.bz2 gdb-%{_target_platform}.tar.bz2
cd ../..
echo ====================TESTING END=====================
%endif

%install
# Initially we're in the %{gdb_src} directory.
cd %{gdb_build}
rm -rf %{buildroot}

make %{?_smp_mflags} install DESTDIR=%{buildroot}

# install the gcore script in /usr/bin
cp $RPM_BUILD_DIR/%{gdb_src}/gdb/gdb_gcore.sh %{buildroot}%{_prefix}/bin/gcore
chmod 755 %{buildroot}%{_prefix}/bin/gcore

# Remove the gdb/gdbtui binaries duplicity.
test -x %{buildroot}%{_prefix}/bin/gdbtui
ln -sf gdb %{buildroot}%{_prefix}/bin/gdbtui
cmp %{buildroot}%{_mandir}/*/gdb.1 %{buildroot}%{_mandir}/*/gdbtui.1
ln -sf gdb.1 %{buildroot}%{_mandir}/*/gdbtui.1

%if 0%{!?_without_python:1}
# Temporarily now:
for LIB in lib lib64;do
  LIBPATH="%{buildroot}%{_datadir}/gdb/auto-load%{_prefix}/$LIB"
  mkdir -p $LIBPATH
  # basename is being run only for the native (non-biarch) file.
  sed -e 's,@pythondir@,%{_datadir}/gdb/python,'		\
      -e 's,@toolexeclibdir@,%{_prefix}/'"$LIB,"		\
      < $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/hook.in	\
      > $LIBPATH/$(basename %{_prefix}/%{_lib}/libstdc++.so.6.*)-gdb.py
done
test ! -e %{buildroot}%{_datadir}/gdb/python/libstdcxx
cp -a $RPM_BUILD_DIR/%{gdb_src}/%{libstdcxxpython}/libstdcxx	\
      %{buildroot}%{_datadir}/gdb/python/libstdcxx
%endif # 0%{!?_without_python:1}

# Remove the files that are part of a gdb build but that are owned and
# provided by other packages.
# These are part of binutils

rm -rf %{buildroot}%{_datadir}/locale/
rm -f %{buildroot}%{_infodir}/bfd*
rm -f %{buildroot}%{_infodir}/standard*
rm -f %{buildroot}%{_infodir}/mmalloc*
rm -f %{buildroot}%{_infodir}/configure*
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}/%{_libdir}/lib{bfd*,opcodes*,iberty*,mmalloc*}

# Delete this too because the dir file will be updated at rpm install time.
# We don't want a gdb specific one overwriting the system wide one.

rm -f %{buildroot}%{_infodir}/dir

%if 0%{!?_with_upstream:1}
# pstack obsoletion

cp -p %{SOURCE3} %{buildroot}%{_mandir}/man1/gstack.1
%if 0%{!?el5:1}
ln -s gstack.1.gz %{buildroot}%{_mandir}/man1/pstack.1.gz
ln -s gstack %{buildroot}+%if 0%{!?el5:1}
%{_bindir}/pstack
%endif # 0%{!?el5:1}
%endif # 0%{!?_with_upstream:1}

%clean
rm -rf %{buildroot}

%post
# This step is part of the installation of the RPM. Not to be confused
# with the 'make install ' of the build (rpmbuild) process.

# For --excludedocs:
if [ -e %{_infodir}/gdb.info.gz ]
then
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/annotate.info.gz || :
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/gdb.info.gz || :
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/gdbint.info.gz || :
  /sbin/install-info --info-dir=%{_infodir} %{_infodir}/stabs.info.gz || :
fi

%preun
if [ $1 = 0 ]
then
  # For --excludedocs:
  if [ -e %{_infodir}/gdb.info.gz ]
  then
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/annotate.info.gz || :
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/gdb.info.gz || :
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/gdbint.info.gz || :
    /sbin/install-info --delete --info-dir=%{_infodir} %{_infodir}/stabs.info.gz || :
  fi
fi

%files
%defattr(-,root,root)
%doc COPYING3 COPYING COPYING.LIB README NEWS
%{_bindir}/gcore
%{_bindir}/gdb
%{_bindir}/gdbtui
%{_mandir}/*/gdb.1*
%{_mandir}/*/gdbtui.1*
%if 0%{!?_with_upstream:1}
%{_bindir}/gstack
%{_mandir}/*/gstack.1*
%if 0%{!?el5:1}
%{_bindir}/pstack
%{_mandir}/*/pstack.1*
%endif # 0%{!?el5:1}
%endif # 0%{!?_with_upstream:1}
%{_datadir}/gdb
%{_infodir}/annotate.info*
%{_infodir}/gdb.info*
%{_infodir}/gdbint.info*
%{_infodir}/stabs.info*

# don't include the files in include, they are part of binutils

%ifnarch sparcv9
%if 0%{!?el5:1}
%files gdbserver
%defattr(-,root,root)
%endif
%{_bindir}/gdbserver
%{_mandir}/*/gdbserver.1*
%endif

%changelog
* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (7.1-4m)
- full rebuild for mo7 release

* Tue May 04 2010 TABUCHI Takaaki <tab@momonga-linux.org>
- (7.1-3m)
- rebuild against readline6

* Sun May  2 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (7.1-2m)
- drop useless patch

* Sat May  1 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (7.1-1m)
- update 7.1
- merge a lot of changes from fedora (gdb-7_1-18_fc13)

* Thu Feb 18 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (6.8.91.20090930-3m)
- rebuild against rpm-4.8.0

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (6.8.91.20090930-2m)
- rebuild against gcc-4.4 and glibc-2.11

* Fri Oct  2 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (6.8.91.20090930-1m)
- update to 6.8.91.20090930
- apply patches from Rawhide (6.8.91.20090930-1)

* Wed Jun 24 2009 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8.50.20090302-1m)
- merge many changes from fedora (6.8.50.20090302-33)
-- switch to 6.8.50 snapshot and archer branch

* Sat Apr 18 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (6.8-10m)
- rebuild against rpm-4.7

* Sat Dec 27 2008 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (6.8-9m)
- sync with trunk (r28804)
- rebuild against rpm-4.6
-- update Patch274 from Rawhide (6.8-33)
-- temporarily drop momonga patch (Patch9999)
- License: GPLv3+

* Thu Nov  6 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-8m)
- merge many bug fixes from fc-devel (gdb-6_8-28_fc10)
- add gdb-6.8-momonga.patch

* Sun Aug 31 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-7m)
- fix version

* Thu Jul 17 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-6m)
- merge many bug fixes from fc-devel (gdb-6_8-17_fc10)

* Sun Jul  6 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-5m)
- merge changes from fc-devel (gdb-6_8-13_fc10)
--* Thu Jul  3 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.8-13
--- Support transparent debugging of inlined functions for an optimized code.
--* Fri Jun 20 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.8-12
--- Remove the gdb/gdbtui binaries duplicity.

* Thu Jun 19 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-4m)
- merge changes from fc-devel (gdb-6_8-11_fc10)

* Tue Jun  3 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-3m)
- merge changes from fc-devel (gdb-6_8-10_fc10)

* Sat Apr 26 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-2m)
- merge changes from fc-devel (gdb-6_8-4_fc10)
- delete unused patches

* Thu Apr 17 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.8-1m)
- update to 6.8 (copy from T4R/gdb r23541)

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (6.7.1-10m)
- rebuild against gcc43

* Sun Feb 24 2008 Ichiro Nakai <ichiro@n.email.ne.jp>
- (6.7.1-9m)
- Obsoletes: pstack

* Fri Feb 22 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.7.1-8m)
- sync with fc-devel (gdb-6_7_1-14_fc9)
--* Thu Feb 21 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-14
--- Rename `set debug build-id' as `set build-id-verbose', former level 1 moved
--  to level 2, default value is now 1, use `set build-id-verbose 0' now to
--  disable the missing separate debug filenames messages (BZ 432164).
--* Wed Feb 20 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-13
--- ia64 build fixes from Doug Chapman (BZ 428882).
--- gdbserver separated into an extra package (BZ 405791).
--- pstack obsoleted by included gstack (BZ 197020).
--- Fix #include <asm/ptrace.h> on kernel-headers-2.6.25-0.40.rc1.git2.fc9.x86_64.
--- Drop the PowerPC simulator as no longer being compatible with Fedora binaries.
--* Thu Feb  7 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-12
--- build-id debug messages print now the library names unconditionally.

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (6.7.1-7m)
- %%NoSource -> NoSource

* Fri Jan 25 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.7.1-6m)
- sync with fc-devel (gdb-6_7_1-11_fc9)
--* Thu Jan 24 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-11
--- Improve the text UI messages for the build-id debug files locating.
--  - Require now the rpm libraries.
--- Fix false `(no debugging symbols found)' on `-readnever' runs.
--- Extend the testcase `gdb.arch/powerpc-prologue.exp' for ppc64.
--* Sat Jan 12 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-10
--- Compilation fixup (-9 was never released).
--* Sat Jan 12 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-9
--- Fix also threaded inferiors for hardware watchpoints after the fork call.
--- Test debugging statically linked threaded inferiors (BZ 239652).
--  - It requires recent glibc to work in this case properly.
--- Testcase cleanup fixup of the gcore memory and time requirements of 6.7.1-8.
--* Thu Jan 10 2008 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-8
--- Fix detaching from a threaded formerly stopped process with non-primary
--  thread currently active (general BZ 233852).
--  - Enable back again the testcases named `attachstop.exp' (no such exist now).
--  - Rename the testcase `gdb.threads/attachstop' to `gdb.threads/attachstop-mt'.
--- Test ia64 memory leaks of the code using libunwind.
--- Testcase delay increase (for BZ 247354).
--- Test gcore memory and time requirements for large inferiors.

* Thu Jan 10 2008 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.7.1-5m)
- sync with fc-devel (gdb-6_7_1-7_fc9)

* Sat Dec 15 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.7.1-4m)
- merged from TSUPPA4RI-branch
- import a patch from fc-devel
--* Mon Dec 10 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-6
--- Testsuite fixes for more stable/comparable results.

* Wed Nov 21 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.7.1-3m)
- added patch to fix compilation issue with gcc43
- imported some changes from fc-devel (gdb-6_7_1-4_fc9)
--* Fri Nov 16 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-4
--- Fix `errno' resolving across separate debuginfo files.
--- Fix segfault on no file loaded, `set debug solib 1', `info sharedlibrary'.
--- Support gdb.fortran/ tests by substituting the g77 compiler by gfortran.

* Sun Nov 11 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.7.1-2m)
- sync with fc-devel (gdb-6_7_1-3_fc9)
--* Sun Nov  4 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-3
--- Fix `errno' resolving on recent glibc with broken DW_AT_MIPS_linkage_name.
--- Imported new test for 6.7 PPC hiding of call-volatile parameter register.
--* Sat Nov  3 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-2
--- Backport `Breakpoints at multiple locations' patch primarily for C++.

* Fri Nov  2 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.7.1-1m)
- copy from trunk/pkgs/gdb r19471
- update to gdb-6.7.1
- sync with fc-devel (gdb-6_7_1-1_fc9)
--* Thu Nov  1 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7.1-1
--- Upgrade to GDB 6.7.1.  Drop redundant patches, forward-port remaining ones.
--* Thu Nov  1 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.7-1
--- Upgrade to GDB 6.7.  Drop redundant patches, forward-port remaining ones.
--- Fix rereading of the main executable on its change.

* Sat Oct 20 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-20m)
- sync with fc-devel (gdb-6_6-37_fc9)
--* Fri Oct 19 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-37
--- Fix hiding unexpected breakpoints on intentional step/next commands.
--- Fix s390 compilation warning/failure due to a wrongly sized type-cast.
--* Sun Oct 14 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-36
--- Fix hardware watchpoints after inferior forks-off some process.
--* Fri Oct 13 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-35
--- Fix non-threaded watchpoints CTRL-C regression on `set follow child'.

* Sat Oct 13 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-19m)
- sync with fc-devel (gdb-6_6-34_fc9)
--* Fri Oct 12 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-34
--- Fix gdbserver for threaded applications and recent glibc (BZ 328021).
--* Tue Oct  9 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-33
--- Fix debug load for sparse assembler files (such as vDSO32 for i386-on-x86_64).
--* Mon Oct  8 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-32
--- Set the breakpoints always to all the ctors/dtors variants (BZ 301701).
--- Fix a TUI visual corruption due to the build-id warnings (BZ 320061).
--- Fixed the kernel i386-on-x86_64 VDSO loading (producing `Lowest section in').
--* Fri Oct  5 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-31
--- Fix address changes of the ctors/dtors breakpoints w/multiple PCs (BZ 301701).
--- Delete an info doc file on `rpmbuild -bp' later rebuilt during `rpmbuild -bc'.

* Fri Sep 28 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-18m)
- sync with fc-devel (gdb-6_6-30_fc8)
--* Tue Sep 25 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-30
--- Fix re-setting of the ctors/dtors breakpoints with multiple PCs (BZ 301701).
--- Avoid one useless user question in the core files locator (build-id).
--* Sun Sep 23 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-29
--- Fixed the kernel VDSO loading (`warning: no loadable sections found in ...').
--- Fix the testcase for pending signals (from BZ 233852).
--* Sat Sep 22 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-28
--- Support also the `$allocate' and `$delete' ctor/dtor variants (BZ 301701).
--- Fix the build compatibility with texinfo >= 4.10.
--- Fix the testcase for pending signals (from BZ 233852).

* Thu Sep 20 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-17m)
- sync with fc-devel (gdb-6_6-27_fc8)
--* Sun Sep 16 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-27
--- Fix attaching to stopped processes and/or pending signals.

* Mon Sep  3 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-16m)
- sync with fc-devel (gdb-6_6-26_fc8)
--* Tue Aug 28 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-26
--- New fast verification whether the .debug file matches its peer (build-id).
--- New locating of the matching binaries from the pure core file (build-id).
--* Fri Aug 17 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-25
--- Fixed excessive RPATH (related to BZ 228891).

* Sun Aug 12 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-15m)
- sync with fc-devel (gdb-6_6-24_fc8)
--* Wed Aug  8 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-24
--- Fixed compatibility with the Rawhide glibc open(2) syscall sanity checking.
--- Update the core_dump_elf_headers=1 compatibility code to the upstream variant.
--* Mon Aug  6 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-23
--- Update PPC unwinding patches to their upstream variants (BZ 140532).
--* Wed Jul 25 2007 Jesse Keating <jkeating@redhat.com> - 6.6-22
--- Rebuild for RH #249435
--* Mon Jul 23 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-21
--- Fixed compatibility with Rawhide kernel fs.binfmt_elf.core_dump_elf_headers=1.
--- .spec file updates to mostly pass RPMLINT - Fedora merge review (BZ 225783).
--- Fixed testcase of the exit of a thread group leader (of BZ 247354).
--- Cleanup any leftover testsuite processes as it may stuck mock(1) builds.

* Mon Jul  9 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-14m)
- sync with fc-devel (gdb-6_6-20_fc8)
--* Sun Jul  8 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-20
--- Do not hang on exit of a thread group leader (BZ 247354).
--- New test for upstream fix of VDSO decoding while attaching to an i386 process.
--- Fixed BZ # 232014 -> 232015.
--* Thu Jul  5 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-19
--- Link with libreadline provided by the operating system.

* Sat Jun 30 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-13m)
- sync with fc-devel (gdb-6_6-18_fc8)
-- 2 bugs are fixed

* Thu Jun 21 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-12m)
- sync with fc-devel (gdb-6_6-16_fc8)

* Wed Jun  6 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-11m)
- sync with f-7 (gdb-6_6-15_fc7)
--* Tue Jun  5 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-15
--- Fix crash on missing filenames debug info (BZ 242155).

* Mon May 28 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-10m)
- sync with fc-devel (gdb-6_6-14_fc7)

* Wed Apr 25 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-9m)
- sync with fc-devel (6.6-11_fc7)
--* Tue Apr 24 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-11
--- Package review, analysed by Ralf Corsepius (BZ 225783).
---- Fix prelink(8) testcase for non-root $PATH missing `/usr/sbin' (BZ 225783).
---- Fix debugging GDB itself - the compiled in source files paths (BZ 225783).
---- Fix harmless GCORE stack buffer overflow, by _FORTIFY_SOURCE=2 (BZ 235753).
---- Fix XML support - the build was missing `expat-devel'.
---- Updated the `info' files handling by the spec file.
---- Building now with the standard Fedora code protections - _FORTIFY_SOURCE=2.
---- Use multiple CPUs for the build (%{?_smp_mflags}).
---- Separate testsuite run to its %check section.
---- Fix (remove) non-ASCII spec file characters.
---- Remove system tools versions dumping - already present in mock build logs.


* Mon Apr 23 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-8m)
- added "ulimit -c unlimited" for testing
- sync with fc-devel (6.6-10_fc7)
--* Sun Apr 22 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-10
--- Notify user of a child forked process being detached (BZ 235197).
--* Sun Apr 22 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-9
--- Allow running `/usr/bin/gcore' with provided but inaccessible tty (BZ 229517).
--- Fix testcase for watchpoints in threads (for BZ 237096).
--- BuildRequires now `libunwind-devel' instead of the former `libunwind'.
--- Use the runtime libunwind .so.7, it requires now >= 0.99-0.1.frysk20070405cvs.

--* Sat Mar 24 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-8
--- Use definition of an empty structure as it is not an opaque type (BZ 233716).
--- Fixed the gdb.base/attachstop.exp testcase false 2 FAILs.

* Thu Mar 22 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-7m)
- sync with fc-devel (6.6-7_fc7)
--* Thu Mar 15 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-7
--- Suggest SELinux permissions problem; no assertion failure anymore (BZ 232371).

* Thu Mar 15 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-6m)
- sync with fc-devel (6.6-6_fc7)
--* Wed Mar 14 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-6
--- Fix occasional dwarf2_read_address: Corrupted DWARF expression (BZ 232353).
--
--* Mon Mar 12 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-5
--- Temporary support for shared libraries >2GB on 64bit hosts. (BZ 231832)
--
--* Sun Feb 25 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-4
--- Backport + testcase for PPC Power6/DFP instructions disassembly (BZ 230000).

* Thu Mar 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (6.6-5m)
- Momonga Linux 3 -> Momonga Linux 4
- fix gcc-4.2
-- gdb-6.6-ada-invalild-cast.patch

* Sun Feb 18 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.6-4m)
- update gdb-6.6
- merged from TSUPPA4RI-branch
-* Tue Feb  6 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
-- (6.6-3m)
-- sync with fc-devel (gdb-6_6-3_fc7)
---* Mon Feb  5 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-3
---- Fix a race during attaching to dying threads; backport (BZ 209445).
---- Testcase of unwinding has now marked its unsolvable cases (for BZ 140532).
-* Sat Jan 27 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
-- (6.6-2m)
-- sync with fc-devel (gdb-6_6-2_fc7)
---* Fri Jan 26 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-2
---- Backported post gdb-6.6 release PPC `show endian' fixup.
---- Fix displaying of numeric char arrays as strings (BZ 224128).
---- Simplified patches by merging upstream accepted ones into a single file.
-* Thu Jan 25 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
-- (6.6-1m)
-- copy from trunk (r13742)
-- add specopt "do_test" to skip testing
-- sync with fc-devel (gdb-6_6-1_fc7)
---* Sat Jan 20 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.6-1
---- Upgrade to GDB 6.6.  Drop redundant patches, forward-port remaining ones.
---- Backported post gdb-6.6 release ia64 unwinding fixups.
---- Testcase for exec() from threaded program (BZ 202689).
---* Mon Jan 15 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-27
---- Fix the testsuite results broken in 6.5-26, stop invalid testsuite runs.

* Sat Jan 13 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.5-12m)
- sync with fc-devel (6.5-26_fc7)
--* Fri Jan 13 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-26
--- Fix unwinding of non-debug (.eh_frame) PPC code, Andreas Schwab (BZ 140532).
--- Fix unwinding of debug (.debug_frame) PPC code, workaround GCC (BZ 140532).
--- Fix missing testsuite .log output of testcases using get_compiler_info().
--* Fri Jan 12 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-25
--- Fix unwinding of non-CFI (w/o debuginfo) PPC code by recent GCC (BZ 140532).
--* Thu Jan 11 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-24
--- Backport readline history for input mode commands like `command' (BZ 215816).

* Wed Jan 10 2007 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.5-11m)
- sync with fc-devel (6.5-23_fc7)
--* Tue Jan  9 2007 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-23
--- Find symbols properly at their original (included) file (BZ 109921).
--- Remove the stuck mock(1) builds disfunctional workaround (-> mock BZ 221351).
--* Sat Dec 30 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-22
--- Fix unwinding crash on older gcj(1) code (extended CFI support) (BZ 165025).
--- Include testcase for the readline history of input mode commands (BZ 215816).
--* Sat Dec 23 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-21
--- Try to reduce sideeffects of skipping ppc .so libs trampolines (BZ 218379).
--- Fix lockup on trampoline vs. its function lookup; unreproducible (BZ 218379).

* Wed Dec 20 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.5-10m)
- sync with fc-devel (6.5-20_fc7)
-* Tue Dec 19 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-20
-- Fix bogus 0x0 unwind of the thread's topmost function clone(3) (BZ 216711).
-- Testcase for readline segfault on excessively long hand-typed lines.

* Wed Dec 13 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.5-9m)
- sync with fc-devel (6.5-19_fc7)
-* Tue Dec 12 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-19
-- Fix attachment also to a threaded stopped process (BZ 219118).
-- Cleanup any leftover testsuite processes as it may stuck mock(1) builds.

* Sat Nov 25 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.5-8m)
- sync with fc-devel (6.5-18_fc7)
-* Sat Nov 25 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-18
-- Fix readline history for input mode commands like `command' (BZ 215816).
-* Wed Nov 16 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-17
-- Bugfix testcase typo of gdb-6.5-16.
-* Wed Nov 16 2006 Jan Kratochvil <jan.kratochvil@redhat.com> - 6.5-16
-- Provide testcase for accessing the last address space byte.

* Sun Nov 12 2006 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (6.5-7m)
- updated to 6.5
- merged from branches/TSUPPA4RI (r12642)

* Sun Jun 25 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (6.3-4m)
- Momonga Linux 2 -> Momonga Linux 3

* Sun Dec 25 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (6.3-3m)
- change version name 
-- RedHat Linux -> Momonga Linux 2

* Sun Dec 25 2005 Yohsuke Ooi <meke@momonga-linux.org>
- (6.3-2m)
- sync from FC(gdb-6.3.0.0-1.94)

* Tue Feb 15 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (6.3-1m)
- update 6.3 and import from FC

* Fri Feb  4 2005 Dai OKUYAMA <dai@ouchi.nahi.to>
- (6.0-2m)
- enable x86_64.

* Mon Mar 29 2004 Toru Hoshina <t@momonga-linux.org>
- (6.0-2m)
- /usr/share/info/annotate.info is missed.

* Mon Mar 22 2004 Toru Hoshina <t@momonga-linux.org>
- (6.0-1m)
- version up. this is expected for kernel 2.6 era, probably.
- dejagnu is also imported, evaluation is needed from now on.

* Sat Mar 20 2004 Toru Hoshina <t@momonga-linux.org>
- (5.3-2m)
- revised spec for enabling rpm 4.2.

* Fri Feb  7 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (5.3-1m)
  update to 5.3

* Mon Jul 29 2002 Tsutomu Yasuda <tom@tom.homelinux.org>
- (5.2.1-1m)
  update to 5.2.1

* Tue Apr 30 2002 Kenta MURATA <muraken@kondara.org>
- (5.1.1-4k)
- /sbin/install-info -> info in PreReq.

* Thu Feb 14 2002 Tsutomu Yasuda <tom@kondara.org>
- (5.1.1-2k)
- fix URL
  update to 5.1.1

* Fri Oct 12 2001 Masaru Sato <masachan@kondara.org>
- add URL tag

* Mon Aug 27 2001 MATSUDA, Daiki <dyky@df-usa.com>
- (5.0-22k)
- removed alpha.patch for building

* Sun Aug 26 2001 Shingo Akagaki <dora@kondara.org>
- release version tar ball

* Sun Mar 18 2001 Toru Hoshina <toru@df-usa.com>
- new snapshot

* Sat Feb 04 2001 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (5.0-15k)
- update source to gdb-20010119.tar.bz2
- Delete gdb-5.0-alpha.patch and gdb-5.0-sparc.patch.
  They have been already included in source.
- don't Exclude sparc

* Thu Nov 09 2000 Kenichi Matsubara <m@kondara.org>
- [5.0-10k]
- bugfix %post.

* Wed Oct 25 2000 MATSUDA, Daiki <dyky@df-usa.com>
- modifiled %post and %preun section from .gz to .bz2

* Tue Aug 08 2000 Toru Hoshina <t@kondara.org>
- rebuild against glibc-2.1.90, X-4.0, rpm-3.0.5.

* Mon Jul 25 2000 Trond Eivind Glomsrod <teg@redhat.com>
- upgrade to CVS snapshot
- excludearch SPARC, build on IA61

* Wed Jul 19 2000 Trond Eivind Glomsrod <teg@redhat.com>
- rebuild

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Sun Jul 02 2000 Trond Eivind Glomsrod <teg@redhat.com>
- rebuild

* Fri Jun 08 2000 Trond Eivind Glomsrod <teg@redhat.com>
- use %%configure, %%makeinstall, %%{_infodir}, %%{_mandir},
  and %%{_tmppath}
- the install scripts  for info are broken(they don't care about
  you specify in the installstep), work around that.
- don't build for IA64

* Mon May 22 2000 Trond Eivind Glomsrod <teg@redhat.com>
- upgraded to 5.0 - dump all patches. Reapply later if needed.
- added the NEWS file to the %%doc files
- don't delete files which doesn't get installed (readline, texinfo)
- let build system handle stripping and gzipping
- don't delete libmmalloc
- apply patch from jakub@redhat.com to make it build on SPARC

* Sun May 20 2000 Takaaki Tabuchi <tab@kondara.org>
- update 5.0.

* Fri Apr 28 2000 Matt Wilson <msw@redhat.com>
- rebuilt against new ncurses

* Sun Apr 02 2000 Takaaki Tabuchi <tab@kondara.org>
- merge redhat-6.2 (4.18-11).

* Tue Mar  7 2000 Jeff Johnson <jbj@redhat.com>
- rebuild for sparc baud rates > 38400.

* Wed Mar 1 2000 Masako Hattori <maru@kondara.org>
- change jman mv->cp

* Wed Feb 23 2000 Masako Hattori <maru@kondara.org>
- do not shake %{_mandir}/ja

* Tue Feb  8 2000 Jakub Jelinek <jakub@redhat.com>
- fix core file handling on i386 with glibc 2.1.3 headers

* Fri Jan 14 2000 Jakub Jelinek <jakub@redhat.com>
- fix reading registers from core on sparc.
- hack around build problems on i386 with glibc 2.1.3 headers

* Thu Oct 7 1999 Jim Kingdon
- List files to install in %{_infodir} specifically (so we don't pick up
things like info.info from GDB snapshots).

* Thu Oct 7 1999 Jim Kingdon
- Update GDB to 19991004 snapshot.  This eliminates the need for the
sigtramp, sparc, xref, and threads patches.  Update sparcmin patch.

* Mon Aug 23 1999 Jim Kingdon
- Omit readline manpage.

* Tue Aug 7 1999 Jim Kingdon
- Remove H.J. Lu's patches (they had been commented out).
- Add sigtramp patch (from gdb.cygnus.com) and threads patch (adapted
from code fusion CD-ROM).

* Wed Apr 14 1999 Jeff Johnson <jbj@redhat.com>
- merge H.J. Lu's patches into 4.18.

* Mon Apr 05 1999 Cristian Gafton <gafton@redhat.com>
- updated the kern22 patch with stuff from davem

* Thu Apr  1 1999 Jeff Johnson <jbj@redhat.com>
- sparc with 2.2 kernels no longer uses sunos ptrace (davem)

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 3)

* Mon Mar  8 1999 Jeff Johnson <jbj@redhat.com>
- Sparc fiddles for Red Hat 6.0.
